@@ -1,39 +1,57 @@
+
 setClass("tidyseurat", contains="Seurat")
 
-#' @importFrom methods show
-#' @import Seurat
-#' @importFrom magrittr %>%
-setMethod(
-  f = "show",
-  signature = "tidyseurat",
-  definition = function(object) {
-
-      object %>%
-      print()
-    
-
-  }
-)
-
 #' tidy for seurat
 #' 
 #' @name tidy
 #' 
 #' @param object A Seurat object
 #' 
+#' @description 
+#' 
+#' DEPRECATED. Not needed any more.
+#' 
 #' @return A tidyseurat object
 #' 
 #' @export
 tidy <- function(object) {  UseMethod("tidy", object) }
 
-#' @importFrom methods as
+#' @importFrom lifecycle deprecate_warn
 #' 
 #' @param object A Seurat object
 #' 
 #' @export
-tidy.Seurat <- function(object){  as(object, "tidyseurat") }
-
+tidy.Seurat <- function(object){ 
+  
+  # DEPRECATE
+  deprecate_warn(
+    when = "0.2.0",
+    what = "tidy()",
+    details = "tidyseurat says: tidy() is not needed anymore."
+  )
+  
+  object
+  
+}
 
+#' @importFrom methods getMethod
+setMethod(
+  f = "show",
+  signature = "Seurat",
+  definition = function(object) {
+    if (isTRUE(x = getOption(x = "restore_Seurat_show", default = FALSE))) {
+      f <- getMethod(
+        f = "show",
+        signature = "Seurat",
+        where = asNamespace(ns = "SeuratObject")
+      )
+      f(object = object)
+    } else {
+      object %>%
+        print()
+    }
+  }
+)
 
 #' Extract and join information for transcripts.
 #'
@@ -51,6 +69,7 @@ tidy.Seurat <- function(object){  as(object, "tidyseurat") }
 #' @param all If TRUE return all
 #' @param exclude_zeros If TRUE exclude zero values
 #' @param shape Format of the returned table "long" or "wide"
+#' @param ... Parameters to pass to join wide, i.e. assay name to extract transcript abundance from
 #'
 #' @details This function extracts information for specified transcripts and returns the information in either long or wide format.
 #'
@@ -59,7 +78,7 @@ tidy.Seurat <- function(object){  as(object, "tidyseurat") }
 #' @examples
 #'
 #' pbmc_small %>% 
-#' tidy %>% 
+#'  
 #' join_transcripts(transcripts = c("HLA-DRA", "LYZ"))
 #'
 #'
@@ -69,7 +88,7 @@ join_transcripts <- function(.data,
                               transcripts = NULL,
                               all = FALSE,
                               exclude_zeros = FALSE,
-                              shape = "long") {
+                              shape = "long", ...) {
   UseMethod("join_transcripts", .data)
 }
 #' @export
@@ -78,17 +97,17 @@ join_transcripts.default <-
            transcripts = NULL,
            all = FALSE,
            exclude_zeros = FALSE,
-           shape = "long")
+           shape = "long", ...)
   {
     print("This function cannot be applied to this object")
   }
 #' @export
-join_transcripts.tidyseurat <-
+join_transcripts.Seurat <-
   function(.data,
            transcripts = NULL,
            all = FALSE,
            exclude_zeros = FALSE,
-           shape = "long")
+           shape = "long", ...)
   {
     
     message("tidyseurat says: A data frame is returned for independent data analysis.")
@@ -115,7 +134,7 @@ join_transcripts.tidyseurat <-
           get_abundance_sc_wide(
             .data = .data,
             transcripts = transcripts,
-            all = all
+            all = all, ...
           ),
           by = "cell"
         ) 
