@@ -57,7 +57,7 @@
 #' 
 #' @export
 #' @examples
-#' pbmc_small %>% tidy %>% as_tibble()
+#' pbmc_small %>%  as_tibble()
 NULL
 
 #' @export
@@ -67,7 +67,7 @@ NULL
 #' @importFrom tibble enframe
 #' 
 #' 
-as_tibble.tidyseurat = function(x, ...,
+as_tibble.Seurat = function(x, ...,
                      .name_repair = c("check_unique", "unique", "universal", "minimal"),
                      rownames = pkgconfig::get_config("tibble::rownames", NULL)){
   x@meta.data %>%
@@ -79,7 +79,7 @@ as_tibble.tidyseurat = function(x, ...,
       
       # Only if I have reduced dimensions and special datasets
       length(x@reductions) > 0 ~ (.) %>% left_join(
-        get_special_datasets(x) %>%
+        get_special_datasets(x, ...) %>%
           map(~ .x %>% when(
             
             # If row == 1 do a trick
@@ -99,4 +99,51 @@ as_tibble.tidyseurat = function(x, ...,
     )
     
     
-}
\ No newline at end of file
+}
+
+#' Get a glimpse of your data
+#'
+#' @description
+#' `r lifecycle::badge("maturing")`
+#'
+#' `glimpse()` is like a transposed version of `print()`:
+#' columns run down the page, and data runs across.
+#' This makes it possible to see every column in a data frame.
+#' It's a little like [str()] applied to a data frame
+#' but it tries to show you as much data as possible.
+#' (And it always shows the underlying data, even when applied
+#' to a remote data source.)
+#'
+#' This generic will be moved to \pkg{pillar}, and reexported from there
+#' as soon as it becomes available.
+#'
+#' @section S3 methods:
+#' `glimpse` is an S3 generic with a customised method for `tbl`s and
+#' `data.frames`, and a default method that calls [str()].
+#'
+#' @param x An object to glimpse at.
+#' @param width Width of output: defaults to the setting of the option
+#'   `tibble.width` (if finite) or the width of the console.
+#' @param ... Unused, for extensibility.
+#' @return x original x is (invisibly) returned, allowing `glimpse()` to be
+#'   used within a data pipe line.
+#'   
+#' @rdname tibble-methods
+#' @name glimpse
+#' 
+#' @export
+#' @examples
+#' pbmc_small %>% tidy %>% glimpse()
+#'
+#'
+NULL
+
+#' @export
+#' @importFrom tibble glimpse
+#' 
+#' 
+glimpse.tidyseurat = function(x, width = NULL, ...){
+  x %>%
+    as_tibble() %>%
+    tibble::glimpse(width = width, ...)
+}
